Manifolds
=========

This is the Sage implementation of manifolds resulting from the
`SageManifolds project <https://sagemanifolds.obspm.fr/>`_.
This section describes only the "manifold" part of SageManifolds;
the pure algebraic part is described in the section
:ref:`tensors-on-free-modules`.

More documentation (in particular example worksheets) can be found
`here <https://sagemanifolds.obspm.fr/documentation.html>`_.

.. toctree::
   :maxdepth: 3

   manifold

   diff_manifold

   riem_manifold

   poisson_manifold

   sage/manifolds/utilities

   sage/manifolds/catalog

.. include:: ../footer.txt
